tensap.approximation.tensor\_approximation.principal\_component\_analysis package
=================================================================================

Submodules
----------

tensap.approximation.tensor\_approximation.principal\_component\_analysis.functional\_tensor\_principal\_component\_analysis module
-----------------------------------------------------------------------------------------------------------------------------------

.. automodule:: tensap.approximation.tensor_approximation.principal_component_analysis.functional_tensor_principal_component_analysis
   :members:
   :undoc-members:
   :show-inheritance:

tensap.approximation.tensor\_approximation.principal\_component\_analysis.tensor\_principal\_component\_analysis module
-----------------------------------------------------------------------------------------------------------------------

.. automodule:: tensap.approximation.tensor_approximation.principal_component_analysis.tensor_principal_component_analysis
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: tensap.approximation.tensor_approximation.principal_component_analysis
   :members:
   :undoc-members:
   :show-inheritance:
